---
feature_story: FS_15_79_76_85
feature_title: line processor
feature_status: TODO
---

This feature defines a concept of (command) line processor.

As of now, there is a single implementation:

*   FS_55_57_45_04 enum selector

    User has to select a function and its args as enum items.

    TODO: TODO_18_51_46_14: refactor FS_42_76_93_51 zero_arg_interp into FS_15_79_76_85 line processor

TODO: Select (command) line processor via FS_42_76_93_51 first arg (zero arg interp).
      Effectively, any new implementation of line processor will have to be selected via zero arg interp.
      Currently, there is one zero arg interp - instead, there can be many and each zero arg value is assigned its own.

NOTE: Any new implementation (e.g. ML) of (command) line processor will likely also require:
      *   Different implementation of REST APIs (see `ServerAction`).
      *   Different implementation of plugins (see `PluginType`).
      *   Different data backend (FS_55_57_45_04 enum selector uses MongoDB APIs).
      *   ...
      But it should|may reuse much of other plumbing (e.g. FS_85_33_46_53 bootstrap or FS_66_17_43_42 test infra).
